@@ -306,7 +306,7 @@ class ArrayModel(QAbstractTableModel):
         try:
             self.test_array[0] = val # will raise an Exception eventually
         except OverflowError as e:
-            print(type(e.message))
+            print(type(e.message))  # spyder: test-skip
             QMessageBox.critical(self.dialog, "Error",
                                  "Overflow error: %s" % e.message)
             return False
